@@ -239,19 +239,19 @@ def _setup_app_event_routes(app_engine: AppEngine,
         if event_info.type == EventType.POST:
             web_server.add_routes([
                 _create_post_event_route(
-                    app_engine, plugin=plugin, event_name=event_name, override_route_name=event_info.route
+                    app_engine, plugin=plugin, event_name=event_name, event_info=event_info
                 )
             ])
         elif event_info.type == EventType.GET:
             web_server.add_routes([
                 _create_get_event_route(
-                    app_engine, plugin=plugin, event_name=event_name, override_route_name=event_info.route
+                    app_engine, plugin=plugin, event_name=event_name, event_info=event_info
                 )
             ])
         elif event_info.type == EventType.MULTIPART:
             web_server.add_routes([
                 _create_multipart_event_route(
-                    app_engine, plugin=plugin, event_name=event_name, override_route_name=event_info.route
+                    app_engine, plugin=plugin, event_name=event_name, event_info=event_info
                 )
             ])
         elif event_info.type == EventType.STREAM and plugin is None:
@@ -282,14 +282,14 @@ def _create_post_event_route(
         app_engine: AppEngine, *,
         plugin: Optional[AppEngine] = None,
         event_name: str,
-        override_route_name: Optional[str]) -> web.RouteDef:
+        event_info: EventDescriptor) -> web.RouteDef:
     """
     Creates route for handling POST event
     """
-    datatype = find_datatype_handler(app_config=app_engine.app_config, event_name=event_name)
+    datatype = find_datatype_handler(app_config=app_engine.app_config, event_name=event_name, event_info=event_info)
     route = app_route_name(app_engine.app_config.app, event_name=event_name,
                            plugin=None if plugin is None else plugin.app_config.app,
-                           override_route_name=override_route_name)
+                           override_route_name=event_info.route)
     logger.info(__name__, f"POST path={route} input={str(datatype)}")
     impl = plugin if plugin else app_engine
     handler = partial(_handle_post_invocation, app_engine, impl,
@@ -304,18 +304,18 @@ def _create_get_event_route(
         app_engine: AppEngine, *,
         plugin: Optional[AppEngine] = None,
         event_name: str,
-        override_route_name: Optional[str]) -> web.RouteDef:
+        event_info: EventDescriptor) -> web.RouteDef:
     """
     Creates route for handling GET requests
     """
     route = app_route_name(app_engine.app_config.app, event_name=event_name,
                            plugin=None if plugin is None else plugin.app_config.app,
-                           override_route_name=override_route_name)
+                           override_route_name=event_info.route)
     logger.info(__name__, f"GET path={route}")
     impl = plugin if plugin else app_engine
     handler = partial(_handle_get_invocation, app_engine, impl, event_name, _auth_types(impl, event_name))
     setattr(handler, '__closure__', None)
-    setattr(handler, '__code__', _handle_post_invocation.__code__)
+    setattr(handler, '__code__', _handle_get_invocation.__code__)
     api_handler = api.add_route('get', route, handler)
     return web.get(route, api_handler)
 
@@ -324,14 +324,14 @@ def _create_multipart_event_route(
         app_engine: AppEngine, *,
         plugin: Optional[AppEngine] = None,
         event_name: str,
-        override_route_name: Optional[str]) -> web.RouteDef:
+        event_info: EventDescriptor) -> web.RouteDef:
     """
     Creates route for handling MULTIPART event
     """
-    datatype = find_datatype_handler(app_config=app_engine.app_config, event_name=event_name)
+    datatype = find_datatype_handler(app_config=app_engine.app_config, event_name=event_name, event_info=event_info)
     route = app_route_name(app_engine.app_config.app, event_name=event_name,
                            plugin=None if plugin is None else plugin.app_config.app,
-                           override_route_name=override_route_name)
+                           override_route_name=event_info.route)
     logger.info(__name__, f"MULTIPART path={route} input={str(datatype)}")
     impl = plugin if plugin else app_engine
     handler = partial(_handle_multipart_invocation, app_engine, impl,
@@ -414,7 +414,7 @@ def _track_ids(request: web.Request) -> Dict[str, str]:
     return {
         'track.operation_id': str(uuid.uuid4()),
         'track.request_id': str(uuid.uuid4()),
-        'track.request_ts': datetime.now().astimezone(timezone.utc).isoformat(),
+        'track.request_ts': datetime.now(tz=timezone.utc).isoformat(),
         **{
             "track." + snakecase(k[8:].lower()): v
             for k, v in request.headers.items() if k.lower().startswith('x-track-')
